function osr = LMdbCropObjects(database, HOMEIMAGES, outputFolder, className, longSide)
%
% Crops and saves object thumbnails for all the images in the database into 
% outputFolder.
% This function can be used in combination with LMquery in order to show
% object crops of a single class. 
%
% If you click in the thumnbail it will show a web address that you can use
% to modify the labeling of that object instance.
%
% LMdbshowobjects(database, HOMEIMAGES)

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% LabelMe, the open annotation tool
% Contribute to the database by labeling objects using the annotation tool.
% http://people.csail.mit.edu/brussell/research/LabelMe/intro.html
% 
% CSAIL, MIT
% 2006
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
if(~exist(outputFolder, 'dir'))
    mkdir(outputFolder);
end

if nargin == 1
    HOMEIMAGES = 'C:\atb\Databases\CSAILobjectsAndScenes\Images'; % you can set here your default folder
end

% find the median aspect ratio 
Nimages = length(database);
%h = waitbar(0,'Finding median aspect ratio...'); 
k = 1;
aspectRatios = zeros(1, Nimages * 3);
objectToSideRatio = aspectRatios;
for i = 1:Nimages
    if isfield(database(i).annotation, 'object')
        Nobjects = length(database(i).annotation.object); n=0;
        try
            img = LMimread(database, i, HOMEIMAGES); % Load image
            if(size(img, 2) < 150)
                continue;
            end
            [nrows ncols c] = size(img);
            for j = 1:Nobjects
                n = n+1;
                [X,Y] = getLMpolygon(database(i).annotation.object(j).polygon);
                
                crop(1) = max(min(X)-2,1);
                crop(2) = min(max(X)+2,ncols);
                crop(3) = max(min(Y)-2,1);
                crop(4) = min(max(Y)+2,nrows);
                crop = round(crop);
               % waitbar(i/Nimages, h, [num2str(i) ' out of ' num2str(Nimages)]);
                aspectRatios(k) = (crop(4) - crop(3)) ./ (crop(2) - crop(1));
                
                objectToSideRatio(k) = (crop(4) - crop(3)) ./size(img,1);
                k = k + 1;
            end
        catch
            disp(sprintf('warning: some problem with image %s/%s',database(i).annotation.folder,database(i).annotation.filename))
        end
    end
end
aspectRatios = aspectRatios(1:k-1);
objectToSideRatio = objectToSideRatio(1:k-1);

AR = median(aspectRatios);
osr = median(objectToSideRatio)
if (AR >1)
    height = longSide;
    width = round(height/AR);
else
    width = longSide;
    height = round(width * AR);
end

%height = round(width * AR);
%h = waitbar(0,'Please wait...');
crop = zeros(4,1);
for i = 1:Nimages
    if isfield(database(i).annotation, 'object')
        Nobjects = length(database(i).annotation.object); n=0;
        try
            img = LMimread(database, i, HOMEIMAGES); % Load image
            [nrows ncols c] = size(img);
            for j = 1:Nobjects
                n = n+1;
                [X,Y] = getLMpolygon(database(i).annotation.object(j).polygon);
                
                crop(1) = max(min(X)-2,1);
                crop(2) = min(max(X)+2,ncols);
                crop(3) = max(min(Y)-2,1);
                crop(4) = min(max(Y)+2,nrows);
                crop = round(crop);
                
                %extend the sides of the bounding box to have the same
                %aspectratio               
                crop = fitBoundingBox(crop, AR, [size(img,1) size(img,2) ]);
                % Image crop:
                %[annotation, Img] = LMimcrop(database(i).annotation, img, crop);
                imgCrop = img(crop(3):crop(4), crop(1):crop(2), :);
              
                imgCrop = imresize(imgCrop, [height width], 'bilinear');
                
                objectFolder = [outputFolder '/' className];
                if(~exist(objectFolder, 'dir'))
                    mkdir(objectFolder);
                end
                imwrite(imgCrop, [ objectFolder '/' database(i).annotation.object(j).name '_' num2str(i) '_' num2str(j) '.jpg'])
                % waitbar(i/Nimages, h, [num2str(i) ' out of ' num2str(Nimages)]);
            end
        catch
            disp(sprintf('warning: some problem with image %s/%s',database(i).annotation.folder,database(i).annotation.filename))
        end
    end
end
