function LMdbWriteImages(database, HOMEIMAGES, outputFolder, className, longSize)
%
% Crops and saves object thumbnails for all the images in the database into 
% outputFolder.
% This function can be used in combination with LMquery in order to show
% object crops of a single class. 
%
% If you click in the thumnbail it will show a web address that you can use
% to modify the labeling of that object instance.
%
% LMdbshowobjects(database, HOMEIMAGES)

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% LabelMe, the open annotation tool
% Contribute to the database by labeling objects using the annotation tool.
% http://people.csail.mit.edu/brussell/research/LabelMe/intro.html
% 
% CSAIL, MIT
% 2006
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

if nargin == 1
    HOMEIMAGES = 'C:\atb\Databases\CSAILobjectsAndScenes\Images'; % you can set here your default folder
end
if(~exist(outputFolder, 'dir'))
    mkdir(outputFolder);
end
% find the median aspect ratio 
Nimages = length(database);
%h = waitbar(0,'Please wait...');
for i = 1:Nimages
    if isfield(database(i).annotation, 'object')
        try
            img = LMimread(database, i, HOMEIMAGES); % Load image
            ar  = size(img,1) /size(img,2);

            if(ar >1)
                height = longSize;
                width =round( height /ar);
            else
                width = longSize;
                height = round(width * ar);
            end
            if(size(img,2) < 300)
                continue;
            end
            img = imresize(img, [height width], 'bilinear');

            objectFolder = [outputFolder '/' className];

            if(~exist(objectFolder, 'dir'))
                mkdir(objectFolder);
            end
            imwrite(img, [ objectFolder '/' database(i).annotation.filename(1:end-4) '.jpg'])
            
            %waitbar(i/Nimages, h, [num2str(i) ' out of ' num2str(Nimages)]);
        catch
            disp(sprintf('warning: some problem with image %s/%s',database(i).annotation.folder,database(i).annotation.filename))
        end
    end
end
