#!/bin/sh
if [ $# -lt 2 ]
then
    echo "<usage>: createobjectdetector.sh <object dir> "
    echo "          <out model folder> <width> <height>"
    echo "<example>: createobjectdetector.sh car/train car_hog 87 55"
    echo "<example>: createobjectdetector.sh bike/train bike_hog 87 85"
    echo "<example>: createobjectdetector.sh bottle/train bottle_hog 32 85"
    echo "<example>: createobjectdetector.sh dog/train dog_hog 79 85"
    echo "<example>: createobjectdetector.sh face/train face_hog 74 85"
    echo "<example>: createobjectdetector.sh lamp/train lamp_hog 54 85"
    echo "<example>: createobjectdetector.sh couch/train couch_hog 85 40"
    echo "<example>: createobjectdetector.sh car+side/train car+side_hog 85 50"
else
    InDir=$1
    OutDir=$2
    WIDTH=$3; export WIDTH
    HEIGHT=$4; export HEIGHT

HardOption=" --poscases 2416 --negcases 12180 "

BinDIR=/scratch/jenny/dalalTriggs/learcode/app
DumpRHOG=$BinDIR/dump_rhog
ClassifyRHOG=$BinDIR/classify_rhog
dump4mc=$BinDIR/dump4svmlearn
svm_learn=svm_learn

Option=" -W $WIDTH,$HEIGHT \
    -C 8,8 -N 2,2 -B 9 -G 8,8 -S 0 --wtscale 2 --maxvalue 0.2 --epsilon 1 \
    --fullcirc 0 -v 3 --proc rgb_sqrt --norm l2hys "

ExtraOption2=" -t 0 -m 0 "
ExtraOption1=" -p 1,0 --no_nonmax 0 -z 8,16,1.3 --cachesize 128 \
    --scaleratio 1.05 --winstride 8 --margin 4,4 --avsize 0,96 "
ExtraOption=$ExtraOption1$ExtraOption2


OutFile=$OutDir/record
CMDLINE=$OutDir/record

CMD="mkdir -p $OutDir"
$CMD 
echo $CMD

# get features on positive images
CMD="$DumpRHOG $Option -s 1  $InDir/pos.lst $OutDir/train_pos.RHOG "
echo $CMD >> $CMDLINE
$CMD >> $OutFile
echo Done with positive images

# get features on negative images
CMD="$DumpRHOG $Option -s 10 $InDir/neg.lst $OutDir/train_neg.RHOG "
echo $CMD >> $CMDLINE
$CMD >> $OutFile
echo Done with negative images
# dump to svmdense format
CMD=" $dump4mc -p $OutDir/train_pos.RHOG -n $OutDir/train_neg.RHOG \
    $OutDir/train_BiSVMLight.blt -v 4 "
echo $CMD >> $CMDLINE
$CMD >> $OutFile

# learn
CMD="$svm_learn -j 3 -B 1 -z c -v 1 -t 0 $OutDir/train_BiSVMLight.blt \
    $OutDir/model_4BiSVMLight.alt "
echo $CMD >> $CMDLINE
$CMD >> $OutFile

echo First iteration complete

## Now test
echo Checking negative images
ExtraOption2=" -t 0 -m 0 --avsize 0 --margin 0"
ExtraOption1=" -p 1 --no_nonmax 1 --nopyramid 0 --scaleratio 1.2 "
ExtraOption=$ExtraOption1$ExtraOption2

ResultDir=$OutDir/WindowTest_Negative
CMD="mkdir -p $ResultDir"
echo $CMD >> $CMDLINE
$CMD >> $OutFile
CMD="$ClassifyRHOG $Option  $ExtraOption \
    $InDir/neg.lst $ResultDir/list.txt $OutDir/model_4BiSVMLight.alt \
    -c $ResultDir/histogram.txt "
echo $CMD >> $CMDLINE
$CMD >> $OutFile

ExtraOption1=" -p 1 --no_nonmax 1 --nopyramid 1 "
ExtraOption=$ExtraOption1$ExtraOption2
echo Checking positive images over scale space
ResultDir=$OutDir/WindowTest_Positive
CMD="mkdir -p $ResultDir"
echo $CMD >> $CMDLINE
$CMD >> $OutFile
CMD="$ClassifyRHOG $Option  $ExtraOption \
    $InDir/pos.lst $ResultDir/list.txt $OutDir/model_4BiSVMLight.alt \
    -c $ResultDir/histogram.txt "
echo $CMD >> $CMDLINE
$CMD >> $OutFile

fi